@@ -30,7 +30,7 @@
  */
 
 /*
- * $Id: etpan-app-subapp.c,v 1.18 2004/11/14 04:37:38 hoa Exp $
+ * $Id: etpan-app-subapp.c,v 1.21 2005/02/06 23:48:56 hoa Exp $
  */
 
 #include "etpan-app-subapp.h"
@@ -49,6 +49,7 @@
 #include <libetpan/libetpan.h>
 #include "etpan-subapp-thread.h"
 #include <string.h>
+#include "etpan-3paned.h"
 
 /* ******************************************* */
 /* color management */
@@ -216,6 +217,10 @@ static void resize_handler_update_window(struct etpan_app * app)
     etpan_subapp_handle_resize(subapp);
   }
   
+  if (etpan_3paned(app)) {
+    etpan_3paned_resize(app);
+  }
+  
   alloc_buffer(app);
   
   resize_handler_winch_received = 0;
@@ -353,9 +358,14 @@ void etpan_app_run(struct etpan_app * app, struct etpan_subapp * subapp)
   
   etpan_app_display_init(app);
   
+  if (etpan_3paned(app)) {
+    etpan_3paned_resize(app);
+  }
+  
+  etpan_app_set_colors(app);
   if (subapp != NULL)
     etpan_app_switch_subapp(subapp, 0);
-
+  
   while (1) {
     fd_set fds;
     int max_fd;
@@ -364,6 +374,7 @@ void etpan_app_run(struct etpan_app * app, struct etpan_subapp * subapp)
     int end;
     int i;
     int min_idle_time;
+    int min_idle_utime;
     
     pthread_mutex_lock(&app->end_lock);
     end = app->end;
@@ -379,7 +390,7 @@ void etpan_app_run(struct etpan_app * app, struct etpan_subapp * subapp)
       if (subapp->enabled)
         etpan_subapp_idle(subapp);
     }
-    
+
     /* display */
     resize_handler_update_window(app);
     
@@ -395,6 +406,7 @@ void etpan_app_run(struct etpan_app * app, struct etpan_subapp * subapp)
       struct etpan_subapp * subapp;
       
       subapp = carray_get(app->zorder, app_index);
+      
       if (subapp->enabled) {
         etpan_subapp_display(subapp);
       }
@@ -435,10 +447,12 @@ void etpan_app_run(struct etpan_app * app, struct etpan_subapp * subapp)
     
     /* minimum idle time */
     min_idle_time = -1;
+    min_idle_utime = 0;
     for(app_index = 0 ; app_index < carray_count(app->subapp_list) ;
         app_index ++) {
       struct etpan_subapp * subapp;
       int idle_time;
+      struct timeval idle_utime;
       
       subapp = carray_get(app->subapp_list, app_index);
       if (subapp->enabled) {
@@ -446,22 +460,44 @@ void etpan_app_run(struct etpan_app * app, struct etpan_subapp * subapp)
         if (idle_time != -1) {
           if (min_idle_time == -1) {
             min_idle_time = idle_time;
+            min_idle_utime = 0;
           }
           else {
             if (idle_time < 0) {
               ETPAN_APP_DEBUG((app, "BUG detected - idle delay of %i by %s",
                                   idle_time, subapp->driver->name));
             }
-            if (idle_time < min_idle_time)
+            if (idle_time <= min_idle_time) {
               min_idle_time = idle_time;
+              min_idle_utime = 0;
+            }
+          }
+        }
+        
+        r = etpan_subapp_get_idle_udelay(subapp, &idle_utime);
+        if (r == 0) {
+          if (min_idle_time == -1) {
+            min_idle_time = idle_utime.tv_sec;
+            min_idle_utime = idle_utime.tv_usec;
+          }
+          else {
+            if ((idle_utime.tv_sec < min_idle_time) ||
+                ((idle_utime.tv_sec == min_idle_time) &&
+                    (idle_utime.tv_usec < min_idle_utime))) {
+              min_idle_time = idle_utime.tv_sec;
+              min_idle_utime = idle_utime.tv_usec;
+            }
           }
         }
       }
     }
+    
     /* fix bug in idle delay */
     if (min_idle_time != -1) {
-      if (min_idle_time <= 0)
-        min_idle_time = 1;
+      if (min_idle_time < 0) {
+        min_idle_time = 0;
+        min_idle_utime = 0;
+      }
     }
     
     /* set cursor */
@@ -472,7 +508,7 @@ void etpan_app_run(struct etpan_app * app, struct etpan_subapp * subapp)
       struct timeval timeout;
       
       timeout.tv_sec = min_idle_time;
-      timeout.tv_usec = 0;
+      timeout.tv_usec = min_idle_utime;
       r = select(max_fd + 1, &fds, NULL, NULL, &timeout);
     }
     else {
@@ -511,13 +547,23 @@ void etpan_app_run(struct etpan_app * app, struct etpan_subapp * subapp)
             if (!current_subapp->driver->always_on_top) {
               switch (ch) {
               case KEY_CTRL('x'):
+              case KEY_CTRL('n'):
                 switch_to_next_app(app, 1);
                 switched = 1;
+                
+                if (etpan_3paned(app)) {
+                  etpan_3paned_check_switch(app);
+                }
                 break;
                 
               case KEY_CTRL('w'):
+              case KEY_CTRL('p'):
                 switch_to_next_app(app, 0);
                 switched = 1;
+                
+                if (etpan_3paned(app)) {
+                  etpan_3paned_check_switch(app);
+                }
                 break;
               }
             }
@@ -905,6 +951,22 @@ etpan_app_find_child_subapp(struct etpan_subapp * app, int enabled)
 
 int etpan_app_subapp_display_init(struct etpan_subapp * app)
 {
+  if (etpan_3paned(app->app)) {
+    struct etpan_subapp * subapp;
+    
+    subapp = etpan_3paned_get_msglist(app->app);
+    if (subapp == app)
+      return NO_ERROR;
+    
+    subapp = etpan_3paned_get_folderlist(app->app);
+    if (subapp == app)
+      return NO_ERROR;
+    
+    subapp = etpan_3paned_get_msgview(app->app);
+    if (subapp == app)
+      return NO_ERROR;
+  }
+  
   app->left = 0;
   app->top = 0;
   app->width = app->app->width - app->left;
