@@ -30,7 +30,7 @@
  */
 
 /*
- * $Id: etpan-cfg-vfolder.c,v 1.16 2004/11/12 13:57:02 hoa Exp $
+ * $Id: etpan-cfg-vfolder.c,v 1.18 2005/01/31 00:40:57 hoa Exp $
  */
 
 #include "etpan-cfg-vfolder.h"
@@ -572,14 +572,24 @@ static int vfolder_collect_folders(struct etpan_db * db,
       continue;
     
     id = etpan_db_entry_get_value(entry, "id");
-    if (strcasecmp(id, "default") != 0)
-      continue;
+    if (id != NULL) {
+      if (strcasecmp(id, "default") == 0) {
+        /* old version compatibility */
+        if (default_folder_name == NULL)
+          default_folder_name = etpan_db_entry_get_value(entry, "folder");
+        if (default_sent_name == NULL)
+          default_sent_name = etpan_db_entry_get_value(entry, "sent");
+        if (default_draft_name == NULL)
+          default_draft_name = etpan_db_entry_get_value(entry, "draft");
+      }
+    }
     
-    default_folder_name = etpan_db_entry_get_value(entry, "folder");
-    default_sent_name = etpan_db_entry_get_value(entry, "sent");
-    default_draft_name = etpan_db_entry_get_value(entry, "draft");
-    
-    break;
+    if (default_folder_name == NULL)
+      default_folder_name = etpan_db_entry_get_value(entry, "default-folder");
+    if (default_sent_name == NULL)
+      default_sent_name = etpan_db_entry_get_value(entry, "default-sent");
+    if (default_draft_name == NULL)
+      default_draft_name = etpan_db_entry_get_value(entry, "default-draft");
   }
   
   /* build initial folder hash */
@@ -937,8 +947,6 @@ static void folder_write(FILE * f, char * id,
   struct mailfolder * sent_folder;
   struct mailfolder * draft_folder;
   
-  fprintf(f, "id = %s\n", id);
-  
   if (folder->fld_virtual_name != NULL) {
     char * virtualname;
     
@@ -1055,14 +1063,13 @@ int etpan_cfg_vfolder_write(char * filename,
   if (f == NULL)
     goto err;
   
-  fprintf(f, "id = default\n");
   if (vfolder_config->default_folder != NULL) {
     char * virtualname;
     
     virtualname =
       etpan_folder_get_virtual_path(vfolder_config->default_folder);
     if (virtualname != NULL) {
-      fprintf(f, "folder = %s\n", virtualname);
+      fprintf(f, "default-folder = %s\n", virtualname);
       free(virtualname);
     }
   }
@@ -1072,7 +1079,7 @@ int etpan_cfg_vfolder_write(char * filename,
     virtualname =
       etpan_folder_get_virtual_path(vfolder_config->sent_folder);
     if (virtualname != NULL) {
-      fprintf(f, "sent = %s\n", virtualname);
+      fprintf(f, "default-sent = %s\n", virtualname);
       free(virtualname);
     }
   }
@@ -1082,7 +1089,7 @@ int etpan_cfg_vfolder_write(char * filename,
     virtualname =
       etpan_folder_get_virtual_path(vfolder_config->draft_folder);
     if (virtualname != NULL) {
-      fprintf(f, "draft = %s\n", virtualname);
+      fprintf(f, "default-draft = %s\n", virtualname);
       free(virtualname);
     }
   }
