@@ -30,7 +30,7 @@
  */
 
 /*
- * $Id: etpan-config.c,v 1.21 2004/12/16 12:57:18 hoa Exp $
+ * $Id: etpan-config.c,v 1.24 2005/02/06 23:48:56 hoa Exp $
  */
 
 #include "etpan-config.h"
@@ -808,7 +808,8 @@ static int etpan_global_config_init(char * config_path,
       ETPAN_DEFAULT_REPLY_QUOTE_LIMIT,
       ETPAN_DEFAULT_NETWORK_TIMEOUT,
       ETPAN_DEFAULT_POLL_DELAY,
-      sendmail_path, 1, 0);
+      sendmail_path, 1, 0, ETPAN_UI_STYLE_BASIC,
+      20, 10);
   if (global_config == NULL)
     goto free_sendmail_path;
   
@@ -972,6 +973,7 @@ static int etpan_sender_config_init(char * config_path,
   char path[PATH_MAX];
   int r;
   struct etpan_sender_item * item;
+  char command[PATH_MAX];
   
   snprintf(path, PATH_MAX, "%s/sender", config_path);
   
@@ -1017,8 +1019,10 @@ static int etpan_sender_config_init(char * config_path,
   
   strncpy(config->default_sender, "sendmail", sizeof(config->default_sender));
   
+  snprintf(command, sizeof(command), "%s -t", ETPAN_DEFAULT_SENDMAIL_PATH);
+  
   item = etpan_sender_item_new("sendmail", SENDER_TYPE_COMMAND,
-      ETPAN_DEFAULT_SENDMAIL_PATH,
+      command,
       NULL, 0, NULL, NULL);
   if (item == NULL) {
     etpan_sender_config_free(config);
@@ -1343,7 +1347,7 @@ int etpan_app_config_init(char * path, struct etpan_app * app,
 
   r = etpan_smime_config_init(path, &config->smime_config);
   if (r != NO_ERROR) {
-    ETPAN_APP_LOG((app, "error initializing abook config"));
+    ETPAN_APP_LOG((app, "error initializing smime config"));
     res = r;
     goto free_abook;
   }
