@@ -30,7 +30,7 @@
  */
 
 /*
- * $Id: etpan-mime-edit-app.c,v 1.30 2004/11/12 13:57:02 hoa Exp $
+ * $Id: etpan-mime-edit-app.c,v 1.32 2005/02/01 02:31:59 hoa Exp $
  */
 
 #include "etpan-mime-edit-app.h"
@@ -74,6 +74,7 @@ static struct etpan_subapp_driver etpan_mime_edit_app_driver = {
   .always_handle_key = 0,
   .always_on_top = 0,
   .get_idle_delay = NULL,
+  .get_idle_udelay = NULL,
   .idle = NULL,
   .set_fd = set_fd,
   .handle_fd = handle_fd,
@@ -1122,6 +1123,7 @@ static void fetch_for_postpone_callback(struct etpan_subapp * app,
   int r;
   struct mailfolder * postpone_folder;
   char * dup_filename;
+  struct etpan_message_append_arg * append_arg;
   
   postpone_folder = data;
 
@@ -1173,13 +1175,24 @@ static void fetch_for_postpone_callback(struct etpan_subapp * app,
   }
   free(fetch_result);
   
+  append_arg = malloc(sizeof(* append_arg));
+  if (append_arg == NULL) {
+    ETPAN_APP_LOG((app->app, "message postpone - not enough memory"));
+    free(dup_filename);
+    goto close;
+  }
+  
+  append_arg->filename = dup_filename;
+  append_arg->flags = NULL;
+  
   r = etpan_subapp_thread_folder_op_add(app, THREAD_ID_MIMEEDIT_POSTPONE,
       ETPAN_THREAD_FOLDER_APPEND_MESSAGE,
       postpone_folder,
       NULL, NULL,
-      dup_filename,
+      append_arg,
       NULL, NULL, NULL);
   if (r != NO_ERROR) {
+    /* leak memory */
     ETPAN_APP_LOG((app->app, "message postpone - not enough memory"));
     return;
   }
