@@ -349,7 +349,6 @@ static int smtp_send_message_with_fields(struct etpan_sender_item * sender,
   
   r = mailsmtp_socket_connect(smtp, sender->host, sender->port);
   if (r != MAILSMTP_NO_ERROR) {
-    mailsmtp_free(smtp);
     
     res = error_from_smtp_error(r);
     goto free_smtp;
@@ -357,18 +356,25 @@ static int smtp_send_message_with_fields(struct etpan_sender_item * sender,
   
   r = mailsmtp_init(smtp);
   if (r != MAILSMTP_NO_ERROR) {
-    mailsmtp_free(smtp);
     
     res = error_from_smtp_error(r);
     goto free_smtp;
   }
   
+  if ((sender->login[0] != '\0') && (sender->password[0] != '\0')) {
+    r = mailsmtp_auth(smtp, sender->login, sender->password);
+    if (r != MAILSMTP_NO_ERROR) {
+      
+      res = error_from_smtp_error(r);
+      goto free_smtp;
+    }
+  }
+  
   r = mailesmtp_send(smtp,
       from, 0, NULL,
       smtp_recipient_list,
       message, length);
   if (r != MAILSMTP_NO_ERROR) {
-    mailsmtp_free(smtp);
     
     res = error_from_smtp_error(r);
     goto free_smtp;
@@ -484,7 +490,8 @@ static int command_send_message(struct etpan_sender_item * sender,
   char * p;
   int source_open;
   int half_close;
-
+  char command[PATH_MAX];
+  
   half_close = 0;
   
   r = pipe(fd_input);
@@ -508,8 +515,13 @@ static int command_send_message(struct etpan_sender_item * sender,
     dup2(fd_output[1], 1);
     dup2(fd_output[1], 2);
     
+#if 0
     execl(sender->command, sender->command, "-t", NULL);
     exit(EXIT_FAILURE);
+#endif
+    snprintf(command, sizeof(command), "%s", sender->command);
+    system(command);
+    exit(EXIT_SUCCESS);
     
   case -1:
     res = ERROR_COMMAND;
@@ -570,8 +582,26 @@ static int command_send_message(struct etpan_sender_item * sender,
       else if (length > 0) {
         if (FD_ISSET(fd_input[1], &write_fds)) {
           ssize_t written_bytes;
+          size_t count;
+          char * temp_p;
           
-          written_bytes = write(fd_input[1], p, length);
+          /* skip CR if there are CR LF */
+          while (* p == '\r') {
+            p ++;
+            length --;
+          }
+          
+          count = 0;
+          temp_p = p;
+          while (count < length) {
+            if (* temp_p == '\r')
+              break;
+            
+            temp_p ++;
+            count ++;
+          }
+          
+          written_bytes = write(fd_input[1], p, count);
           if (written_bytes < 0) {
             break;
           }
